@@ -107,8 +107,8 @@ void ast_console_toggle_loglevel(int fd, int level, int state);
 
 /* Note: The AST_LOG_* macros below are the same as
  * the LOG_* macros and are intended to eventually replace
- * the LOG_* macros to avoid name collisions as has been
- * seen in app_voicemail. However, please do NOT remove
+ * the LOG_* macros to avoid name collisions with the syslog(3)
+ * log levels. However, please do NOT remove
  * the LOG_* macros from the source since these may be still
  * needed for third-party modules
  */
@@ -168,7 +168,7 @@ void ast_console_toggle_loglevel(int fd, int level, int state);
 #ifdef AST_LOG_VERBOSE
 #undef AST_LOG_VERBOSE
 #endif
-#define LOG_VERBOSE    __LOG_VERBOSE, _A_
+#define AST_LOG_VERBOSE    __LOG_VERBOSE, _A_
 
 #ifdef LOG_DTMF
 #undef LOG_DTMF
